@@ -6,6 +6,8 @@ package gl4gcj;
 * <dl>
 *   <dt> gl4gcj </dt>
 *   <dd> OpenGL gcj binding.</dd>
+*   <dt> glu4gcj</dt>
+*   <dd> GLU gcj binding.</dd>
 *   <dt> glut4gcj</dt>
 *   <dd> GLUT gcj binding.</dd>
 * </dl>
@@ -47,12 +49,13 @@ public class GL implements GLConstants
 	public static native boolean glIsEnabled(int cap);
 	public static native void glEnableClientState(int cap);
 	public static native void glDisableClientState(int cap);
-	public static native boolean[] glGetBooleanv(int pname);
-	/*
+
+	//?? dangerous...  no params size check
+	public static native void glGetBooleanv(int pname, boolean[] params);
 	public static native void glGetDoublev(int pname,  double[] params);
 	public static native void glGetFloatv(int pname,  float[] params);
 	public static native void glGetIntegerv(int pname,  int[] params);
-	*/
+
 	public static native void glPushAttrib(int mask);
 	public static native void glPopAttrib();
 	public static native void glPushClientAttrib(int mask);
@@ -131,12 +134,12 @@ public class GL implements GLConstants
 	public static native void glTranslatef(float x, float y, float z);
 
 	// Display Lists
-	public static native boolean glIsList(long list);
-	public static native void glDeleteLists(long list, int range);
-	public static native long glGenLists(int range);
-	public static native void glNewList(long list, int mode);
+	public static native boolean glIsList(int list);
+	public static native void glDeleteLists(int list, int range);
+	public static native int glGenLists(int range);
+	public static native void glNewList(int list, int mode);
 	public static native void glEndList();
-	public static native void glCallList(long list);
+	public static native void glCallList(int list);
 
 	public static native void glCallLists(byte[] lists);
 	public static native void glCallLists(short[] lists);
