@@ -268,30 +268,22 @@ GL::glDisableClientState (jint cap)
 }
 
 
-jbooleanArray
-GL::glGetBooleanv (jint pname)
+void
+GL::glGetBooleanv (jint pname, jbooleanArray params)
 {
 	JvInitClass(&GL::class$);
-	jbooleanArray params = NULL;
-	if (pname == GL_COLOR_WRITEMASK)
-		params = JvNewBooleanArray(4);
-	else
-		params = JvNewBooleanArray(1);
 
 	jboolean* native_params = elements(params);
 	::glGetBooleanv(pname, (GLboolean*)native_params);
-
-	return params;
 }
 
 
-/*
 void
 GL::glGetDoublev (jint pname, jdoubleArray params)
 {
 	JvInitClass(&GL::class$);
-//	jdouble* native_params = elements(params);
-//	::glGetDoublev (pname, native_params)
+	jdouble* native_params = elements(params);
+	::glGetDoublev (pname, (GLdouble*)native_params);
 }
 
 
@@ -299,8 +291,8 @@ void
 GL::glGetFloatv (jint pname, jfloatArray params)
 {
 	JvInitClass(&GL::class$);
-//	jfloat* native_params = elements(params);
-//	::glGetFloatv (pname, native_params);
+	jfloat* native_params = elements(params);
+	::glGetFloatv (pname, (GLfloat*)native_params);
 }
 
 
@@ -308,10 +300,9 @@ void
 GL::glGetIntegerv (jint pname, jintArray params)
 {
 	JvInitClass(&GL::class$);
-//	jint* native_params = elements(params);
-//	::glGetIntegerv (pname, native_params);
+	jint* native_params = elements(params);
+	::glGetIntegerv (pname, (GLint*)native_params);
 }
-*/
 
 
 void
@@ -607,7 +598,7 @@ GL::glTranslatef (jfloat x, jfloat y, jfloat z)
 // Display Lists
 
 jboolean
-GL::glIsList (jlong list)
+GL::glIsList (jint list)
 {
 	JvInitClass(&GL::class$);
 	jboolean result = ::glIsList ((GLuint)list); 
@@ -616,25 +607,25 @@ GL::glIsList (jlong list)
 
 
 void
-GL::glDeleteLists (jlong list, jint range)
+GL::glDeleteLists (jint list, jint range)
 {
 	JvInitClass(&GL::class$);
 	::glDeleteLists (list, range);
 }
 
 
-jlong
+jint
 GL::glGenLists (jint range)
 {
 	JvInitClass(&GL::class$);
-	jlong result = 0;
+	jint result = 0;
 	result = ::glGenLists (range);
 	return result;
 }
 
 
 void
-GL::glNewList (jlong list, jint mode)
+GL::glNewList (jint list, jint mode)
 {
 	JvInitClass(&GL::class$);
 	::glNewList (list, mode);
@@ -650,7 +641,7 @@ GL::glEndList ()
 
 
 void
-GL::glCallList (jlong list)
+GL::glCallList (jint list)
 {
 	JvInitClass(&GL::class$);
 	::glCallList (list);
